# [Introduction](@id structures-intro)

There are several specialist data structures that can be used to
interact with HiGHS when using [`C++`](@ref cpp-getting-started) and
[`Python`](@ref python-getting-started), and they are defined in the
sections on [enums](@ref structures-enums) and [classes](@ref
classes-overview). The advantage using these classes is that many
fewer parameters are needed when passing data to and from
HiGHS. However, the use of classes is not necessary for the basic use
of `highspy`. As with the `C` and `Fortran` interfaces, there are
equivalent methods that use simple scalars and vectors of data.

